@@ -1,6 +1,8 @@
 import requests
+import asyncio
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
+from concurrent.futures import ThreadPoolExecutor
 
 from .__version__ import __version__
 
@@ -8,8 +10,11 @@ from .__version__ import __version__
 class ZenRowsClient:
     api_url = "https://api.zenrows.com/v1/"
 
-    def __init__(self, apikey: str, retries: int = 0):
+    def __init__(self, apikey: str, retries: int = 0, concurrency: int = 5):
         self.apikey = apikey
+
+        self.executor = ThreadPoolExecutor(max_workers=concurrency)
+
         self.requests_session = requests.Session()
         if (retries > 0):
             max_retries = Retry().new(
@@ -23,6 +28,13 @@ class ZenRowsClient:
             self.requests_session.mount("http://", adapter)
 
     def get(self, url: str, params: dict = None, headers: dict = None, **kwargs) -> requests.Response:
+        return self._worker(url, params, headers, **kwargs)
+
+    async def get_async(self, url: str, params: dict = None, headers: dict = None, **kwargs) -> requests.Response:
+        loop = asyncio.get_event_loop()
+        return await loop.run_in_executor(self.executor, self._worker, url, params, headers, **kwargs)
+
+    def _worker(self, url: str, params: dict = None, headers: dict = None, **kwargs):
         if not params:
             params = {}
 
